import { default as React } from 'react';
import { Factory, CssKnownProps, CssRule, CssStyleCollection, CssVars } from '@cssfn/core';
import { EventHandler } from '@reusable-ui/hooks';
import { SemanticProps } from '@reusable-ui/semantics';
import { AccessibilityProps } from '@reusable-ui/accessibilities';
import { OutlineableProps } from '@reusable-ui/outlineable';
import { MildableProps } from '@reusable-ui/mildable';
export interface ActivatableVars {
    filterActive: any;
    animActive: any;
    animPassive: any;
    filter: any;
    anim: any;
}
export declare const ifActivated: (styles: CssStyleCollection) => CssRule;
export declare const ifActivating: (styles: CssStyleCollection) => CssRule;
export declare const ifPassivating: (styles: CssStyleCollection) => CssRule;
export declare const ifPassivated: (styles: CssStyleCollection) => CssRule;
export declare const ifActive: (styles: CssStyleCollection) => CssRule;
export declare const ifPassive: (styles: CssStyleCollection) => CssRule;
export declare const ifActivePassivating: (styles: CssStyleCollection) => CssRule;
export interface ActivatableStuff {
    activatableRule: Factory<CssRule>;
    activatableVars: CssVars<ActivatableVars>;
}
export interface ActivatableConfig {
    filterActive?: CssKnownProps['filter'];
    animActive?: CssKnownProps['animation'];
    animPassive?: CssKnownProps['animation'];
}
/**
 * Adds a capability of UI to be highlighted/selected/activated.
 * @param config  A configuration of `activatableRule`.
 * @returns A `ActivatableStuff` represents an activatable state.
 */
export declare const usesActivatable: (config?: ActivatableConfig) => ActivatableStuff;
export interface MarkActiveOptions {
    outlined?: null | OutlineableProps['outlined'];
    mild?: null | MildableProps['mild'];
}
export declare const markActive: (options?: MarkActiveOptions) => CssRule;
export interface ActivatableProps extends Partial<Pick<AccessibilityProps, 'active' | 'inheritActive'>> {
}
export declare const useActivatable: <TElement extends Element = HTMLElement>(props: ActivatableProps & SemanticProps) => {
    active: boolean;
    isVisible: boolean;
    class: string | null;
    props: {
        checked: boolean;
        'aria-checked'?: undefined;
        'aria-pressed'?: undefined;
        'aria-selected'?: undefined;
    } | {
        'aria-checked': boolean;
        checked?: undefined;
        'aria-pressed'?: undefined;
        'aria-selected'?: undefined;
    } | {
        'aria-pressed': boolean;
        checked?: undefined;
        'aria-checked'?: undefined;
        'aria-selected'?: undefined;
    } | {
        'aria-selected': boolean;
        checked?: undefined;
        'aria-checked'?: undefined;
        'aria-pressed'?: undefined;
    } | null;
    handleAnimationStart: React.AnimationEventHandler<TElement>;
    handleAnimationEnd: React.AnimationEventHandler<TElement>;
    handleAnimationCancel: React.AnimationEventHandler<TElement>;
};
export interface ActiveChangeEvent {
    active: boolean;
}
export interface ToggleActivatableProps<TActiveChangeEvent extends ActiveChangeEvent = ActiveChangeEvent> extends ActivatableProps, AccessibilityProps {
    defaultActive?: boolean;
    onActiveChange?: EventHandler<TActiveChangeEvent>;
}
export declare const useToggleActivatable: <TActiveChangeEvent extends ActiveChangeEvent = ActiveChangeEvent>(props: ToggleActivatableProps<TActiveChangeEvent>, changeEventTarget?: (React.RefObject<HTMLInputElement> | null)) => readonly [boolean, React.Dispatch<React.SetStateAction<boolean>>, React.Dispatch<void>];
